# likepep403 [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

A library containing several useful Python decorators. Called `decorlib` before
1.0.1, it is now called `likepep403` due to the fact functions provided by this
package can simulate many things that [PEP 403](https://peps.python.org/pep-0403/)
can do once it's in official consideration.

## Available decorators

All decorators' descriptions can be seen in [the docs](https://github.com/Keyacom/likepep403/tree/main/docs).
